<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>TreeWindow</name>
    <message>
        <location filename="../treewindow.ui" line="14"/>
        <source>Panel DOM Tree</source>
        <translation>DOM strom panelu</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="63"/>
        <location filename="../treewindow.ui" line="96"/>
        <source>Property</source>
        <translation>Vlastnost</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="68"/>
        <source>Value</source>
        <translation>Hodnota</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="76"/>
        <source>All properties</source>
        <translation>Všechny vlastnosti</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="101"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="106"/>
        <source>String value</source>
        <translation>Hodnota řetězce</translation>
    </message>
</context>
</TS>
